@@ -9,24 +9,33 @@ To get started with coBib you must run:
 ```
 cobib init
 ```
-This will initialize the database in the location specified by `config.database.file`.
+This will initialize the database in the location specified by
+`cobib.config.config.DatabaseConfig.file`.
 
-If you enabled the automatic git-integration of coBib via `config.database.git`, you must initialize
-this separately via:
+If you enabled the automatic git-integration of coBib via `cobib.config.config.DatabaseConfig.git`,
+you must initialize this separately via:
 ```
 cobib init --git
 ```
 If you have not run the first command yet, you can directly initialize the database *and* the
 git-integration by only running the second command.
+
+.. warning::
+   You can**not** run this command from the TUI, because the database must have already been
+   initialized *before* you can start the TUI in the first place.
 """
 
 from __future__ import annotations
 
-import argparse
 import logging
 import os
 import sys
-from typing import IO, TYPE_CHECKING, Any, List
+from pathlib import Path
+
+from rich.console import Console
+from rich.prompt import PromptBase, PromptType
+from textual.app import App
+from typing_extensions import override
 
 from cobib.config import Event, config
 from cobib.utils.rel_path import RelPath
@@ -34,46 +43,53 @@ from cobib.utils.rel_path import RelPath
 from .base_command import ArgumentParser, Command
 
 LOGGER = logging.getLogger(__name__)
-
-if TYPE_CHECKING:
-    import cobib.tui
+"""@private module logger."""
 
 
 class InitCommand(Command):
-    """The Init Command."""
+    """The Init Command.
+
+    This command can parse the following arguments:
+
+        * `-g`, `--git`: initializes the git-integration.
+    """
 
     name = "init"
 
-    def execute(self, args: List[str], out: IO[Any] = sys.stdout) -> None:
-        """Initializes the database.
+    @override
+    def __init__(
+        self,
+        *args: str,
+        console: Console | App[None] | None = None,
+        prompt: type[PromptBase[PromptType]] | None = None,
+    ) -> None:
+        super().__init__(*args, console=console, prompt=prompt)
 
-        Initializes the YAML database in the location specified by `config.database.file`.
-        If you enabled `config.database.git` *and* you specify the `--git` command-line argument,
-        the git-integration will be initialized, too.
+        self.file: Path
+        """The path to the database file."""
 
-        Args:
-            args: a sequence of additional arguments used for the execution. The following values
-                are allowed for this command:
-                    * `-g`, `--git`: initializes the git-integration.
-            out: the output IO stream. This defaults to `sys.stdout`.
-        """
-        LOGGER.debug("Starting Init command.")
+        self.root: Path
+        """The parent directory where the database file resides. This is where the git repository
+        gets initialized (if the git integration was enabled)."""
+
+    @override
+    @classmethod
+    def init_argparser(cls) -> None:
         parser = ArgumentParser(prog="init", description="Init subcommand parser.")
         parser.add_argument("-g", "--git", action="store_true", help="initialize git repository")
+        cls.argparser = parser
 
-        try:
-            largs = parser.parse_args(args)
-        except argparse.ArgumentError as exc:
-            LOGGER.error(exc.message)
-            return
+    @override
+    def execute(self) -> None:
+        LOGGER.debug("Starting Init command.")
 
-        Event.PreInitCommand.fire(largs)
+        Event.PreInitCommand.fire(self)
 
-        file = RelPath(config.database.file).path
-        root = file.parent
+        self.file = RelPath(config.database.file).path
+        self.root = self.file.parent
 
-        file_exists = file.exists()
-        git_tracked = (root / ".git").exists()
+        file_exists = self.file.exists()
+        git_tracked = (self.root / ".git").exists()
 
         if file_exists:
             if git_tracked:
@@ -84,19 +100,19 @@ class InitCommand(Command):
                 LOGGER.info(msg)
                 return
 
-            if not git_tracked and not largs.git:
+            if not git_tracked and not self.largs.git:
                 msg = "Database file already exists! Use --git to start tracking it with git."
                 LOGGER.warning(msg)
                 return
 
         else:
-            LOGGER.debug('Creating path for database file: "%s"', root)
-            root.mkdir(parents=True, exist_ok=True)
+            LOGGER.debug('Creating path for database file: "%s"', self.root)
+            self.root.mkdir(parents=True, exist_ok=True)
 
-            LOGGER.debug('Creating empty database file: "%s"', file)
-            open(file, "w", encoding="utf-8").close()  # pylint: disable=consider-using-with
+            LOGGER.debug('Creating empty database file: "%s"', self.file)
+            open(self.file, "w", encoding="utf-8").close()  # pylint: disable=consider-using-with
 
-        if largs.git:
+        if self.largs.git:
             if not config.database.git:
                 msg = (
                     "You are about to initialize the git tracking of your database, but this will "
@@ -118,15 +134,8 @@ class InitCommand(Command):
                 )
                 LOGGER.warning(msg)
                 sys.exit(1)
-            LOGGER.debug('Initializing git repository in "%s"', root)
-            os.system(f"git init {root}")
-            self.git(args=vars(largs), force=True)
+            LOGGER.debug('Initializing git repository in "%s"', self.root)
+            os.system(f"git init {self.root}")
+            self.git(force=True)
 
-        Event.PostInitCommand.fire(root, file)
-
-    @staticmethod
-    def tui(tui: cobib.tui.TUI) -> None:
-        """🛑 This command is *not* available via the TUI.
-
-        This is the case because the TUI cannot be started before the database has been initialized.
-        """
+        Event.PostInitCommand.fire(self)
