@@ -4,12 +4,10 @@ Since version 3.0 coBib is configured through a Python file.
 For documentation purposes this example configuration lists all possible settings with their default
 values and detailed explanations.
 
-Internally, coBib's configuration is nothing but a (nested) Python dictionary. However, for ease of
-usage all of its fields are also exposed as attributes. This means, that the following two lines are
-equivalent:
+Internally, coBib's configuration is nothing but a (nested) Python dataclass. This means, you can
+simply change any setting via an attribute like so:
 
 ```python
-config['database']['git'] = True
 config.database.git = True
 ```
 """
@@ -19,7 +17,7 @@ import os
 import sys
 
 # To get started you must import coBib's configuration.
-from cobib.config import LabelSuffix, config
+from cobib.config import LabelSuffix, TagMarkup, config
 
 # Now, you are all set to apply your own settings.
 
@@ -36,19 +34,41 @@ config.logging.version = "~/.cache/cobib/version"
 # COMMANDS
 # These settings affect some command specific behavior.
 
+# You can specify whether the automatic file download should be skipped during entry addition.
+config.commands.add.skip_download = False
+
+# You can specify whether you should be prompted for confirmation before deleting an entry.
+config.commands.delete.confirm = True
+# You can specify whether associated files should be preserved during entry deletion.
+config.commands.delete.preserve_files = False
+
 # You can specify the default bibtex entry type.
 config.commands.edit.default_entry_type = "article"
-
-# You can specify the editor program.
+# You can specify the editor program. Note, that this default will respect your `$EDITOR`
+# environment setting and fall back to `vim` if that variable is not set.
 config.commands.edit.editor = os.environ.get("EDITOR", "vim")
-# Note, that this default will respect your `$EDITOR` environment setting and fallback to `vim` if
-# that variable is not set.
+# You can specify whether associated files should be preserved when renaming during editing.
+config.commands.edit.preserve_files = False
+
+# You can specify whether downloading of attachments inside the imported library should be skipped.
+config.commands.import_.skip_download = False
+
+# You can configure the default columns displayed during the list command.
+config.commands.list_.default_columns = ["label", "title"]
+# You can specify whether filter matching should be performed case-insensitive.
+config.commands.list_.ignore_case = False
+
+# You can specify whether associated files should be preserved when renaming during modifying.
+config.commands.modify.preserve_files = False
 
 # You can specify a custom command which will be used to `open` files associated with your entries.
 config.commands.open.command = "xdg-open" if sys.platform.lower() == "linux" else "open"
 # You can specify the names of the data fields which are to be checked for openable URLs.
 config.commands.open.fields = ["file", "url"]
 
+# You can specify the default number of context lines to be provided for each search query match.
+# This is similar to the `-C` option of `grep`.
+config.commands.search.context = 1
 # You can specify a custom grep tool which will be used to search through your database and any
 # associated files. The default tool (`grep`) will not provide results for attached PDFs but other
 # tools such as [ripgrep-all](https://github.com/phiresky/ripgrep-all) will.
@@ -81,18 +101,21 @@ config.database.git = False
 
 # You can specify a default label format which will be used for the database entry keys. The format
 # of this option follows the f-string like formatting of modifications (see also the documentation
-# of the [ModifyCommand](https://mrossinek.gitlab.io/cobib/cobib/commands/modify.html)). The default
-# configuration value leaves the label unchanged compared to the metadata provided by the source
-# from which the entry gets added. A more useful example is `"{author.split()[1]}{year}"` which
-# takes the surname of the first author and immediately appends the publication year.
-config.database.format.label_default = "{label}"
+# of the [ModifyCommand](https://cobib.gitlab.io/cobib/cobib/commands/modify.html)). The default
+# configuration value passes the originally provided label through
+# [text-unidecode](https://pypi.org/project/text-unidecode/) which replaces all Unicode symbols with
+# pure ASCII ones. A more useful example is
+#     `"{unidecode(author[0].last)}{year}"`
+# which takes the surname of the first author, replaces the Unicode characters and then immediately
+# appends the publication year.
+config.database.format.label_default = "{unidecode(label)}"
 
 # You can specify the suffix format which is used to disambiguate labels if a conflict would occur.
 # This option takes a tuple of length 2, where the first entry is the string separating the proposed
 # label from the enumerator and the second one is one of the enumerators provided in the
 # `config.LabelSuffix` object. The available enumerators are:
 #   - ALPHA: a, b, ...
-#   - CAPTIAL: A, B, ...
+#   - CAPITAL: A, B, ...
 #   - NUMERIC: 1, 2, ...
 config.database.format.label_suffix = ("_", LabelSuffix.ALPHA)
 
@@ -121,85 +144,52 @@ config.parsers.bibtex.ignore_non_standard_types = False
 # used, *significantly* increasing the performance of the parsing. Note, that this requires manual
 # installation of the C-based parser:
 # https://yaml.readthedocs.io/en/latest/install.html#optional-requirements
-config.parsers.yaml.use_c_lib_yaml = False
+config.parsers.yaml.use_c_lib_yaml = True
+
+# THEME
+
+# You can configure the search label and query highlights.
+config.theme.search.label = "blue"
+config.theme.search.query = "red"
+
+# You can also configure the markup used for the following builtin special tags:
+config.theme.tags.new = TagMarkup(10, "bold bright_cyan")
+config.theme.tags.high = TagMarkup(40, "on bright_red")
+config.theme.tags.medium = TagMarkup(30, "bright_red")
+config.theme.tags.low = TagMarkup(20, "bright_yellow")
+# None of these tags are added automatically, but you can do this easily with a `PostAddCommand`
+# hook like so:
+#
+#    @Event.PostAddCommand.subscribe
+#    def add_new_tag(cmd: AddCommand) -> None:
+#        for entry in cmd.new_entries.values():
+#            if "new" not in entry.tags:
+#                entry.tags = entry.tags + ["new"]
+#
+# Note, that the `new` tag has a lower weight than all of the builtin priority tags (`high`,
+# `medium`, `low`) allowing these to be used to further classify new entries on a reading list.
+
+# You can even specify your own tag names which should be treated with special markup.
+# Because the markup names are used in a `rich.Theme`, they must be lower case, start with a letter,
+# and only contain letters or the characters `"."`, `"-"`, `"_"`.
+config.theme.tags.user_tags = {}
 
 # TUI
-# These settings affect the functionality and look of the TUI.
 
-# You can specify a list of default arguments for the default list view.
-config.tui.default_list_args = ["-l"]
-
-# You can disable the prompt before quitting coBib by turning off the following setting:
-config.tui.prompt_before_quit = True
-
-# You can specify whether the list view of the TUI should be reversed. By default, this is enabled,
-# because this will place the most recently added entries at the top of the TUI.
-config.tui.reverse_order = True
-
-# You can specify a scroll offset. This corresponds to the number of lines which will be kept
-# visible above or below the cursor line while scrolling the buffer. If you set this number to
-# something very large (e.g. 99) you can pin the cursor line to the center of the window during
-# scrolling.
-# Note: if you are a Vim user, this setting will feel similar to `scrolloff`.
-config.tui.scroll_offset = 3
-
-# TUI.COLORS
-# With the following color settings you can change the look of the TUI. Each of these settings
-# accepts any of the following color names: `black`, `red`, `green`, `yellow`, `blue`, `magenta`,
-# `cyan` and `white`.
-config.tui.colors.cursor_line_fg = "white"
-config.tui.colors.cursor_line_bg = "cyan"
-config.tui.colors.top_statusbar_fg = "black"
-config.tui.colors.top_statusbar_bg = "yellow"
-config.tui.colors.bottom_statusbar_fg = "black"
-config.tui.colors.bottom_statusbar_bg = "yellow"
-config.tui.colors.search_label_fg = "blue"
-config.tui.colors.search_label_bg = "black"
-config.tui.colors.search_query_fg = "red"
-config.tui.colors.search_query_bg = "black"
-config.tui.colors.popup_help_fg = "white"
-config.tui.colors.popup_help_bg = "green"
-config.tui.colors.popup_stdout_fg = "white"
-config.tui.colors.popup_stdout_bg = "blue"
-config.tui.colors.popup_stderr_fg = "white"
-config.tui.colors.popup_stderr_bg = "red"
-config.tui.colors.selection_fg = "white"
-config.tui.colors.selection_bg = "magenta"
-
-# Note: if your terminal supports it, you can even try to override the color specifications right
-# from within coBib. The check whether your terminal supports this relies on the
-# `curses.can_change_color()` function, which is more or less documented
-# [here](https://docs.python.org/3/library/curses.html#curses.can_change_color).
-# You can attempt to get this to work by overwriting the named colors with a `#RRGGBB` value like
-# so:
-#     config.tui.colors.black = `#222222`
-# , which changes the black definition into a more mallow gray.
-
-# TUI.KEY_BINDINGS
-# You can also change the default key bindings of the TUI by overwriting any of the following
-# settings with a different key.
-config.tui.key_bindings.add = "a"
-config.tui.key_bindings.delete = "d"
-config.tui.key_bindings.edit = "e"
-config.tui.key_bindings.export = "x"
-config.tui.key_bindings.filter = "f"
-config.tui.key_bindings.help = "?"
-config.tui.key_bindings["import"] = "i"  # since `import` is a keyword, this syntax is required
-config.tui.key_bindings.modify = "m"
-config.tui.key_bindings.open = "o"
-config.tui.key_bindings.prompt = ":"
-config.tui.key_bindings.quit = "q"
-config.tui.key_bindings.redo = "r"
-config.tui.key_bindings.search = "/"
-config.tui.key_bindings.select = "v"
-config.tui.key_bindings.show = "ENTER"
-config.tui.key_bindings.sort = "s"
-config.tui.key_bindings.undo = "u"
-config.tui.key_bindings.wrap = "w"
-# Note, the exception of the key for `show` which is set to the custom `ENTER` string. When coBib
-# encounters this string it will automatically map to the ASCII codes 10 and 13 (corresponding to
-# the `line feed` and `carriage return`, respectively). Any other string is interpreted a single
-# character whose ASCII value is used as the trigger.
+# You can configure the minimum number of lines to keep above and below the cursor in the TUI's list
+# view. This is similar to Vim's `scrolloff` setting.
+config.tui.scroll_offset = 2
+# You can provide a list of preset filters. These can be interactively selected in the TUI by
+# pressing `p`. To specify these, simply provide a string with the filter arguments, for example:
+#
+#     config.tui.preset_filters = [
+#         "++tags READING",
+#         "++year 2023",
+#     ]
+#
+# The first 9 filters can be quickly accessed in the TUI by simply pressing the corresponding
+# number. You can also use 0 to reset any applied filter.
+config.tui.preset_filters = []
 
 # UTILS
 
@@ -243,4 +233,4 @@ config.events = {}
 #
 # Note, that the typing is required for the config validation to pass!
 # For more information refer to the
-# [online documentation](https://mrossinek.gitlab.io/cobib/cobib/config/event.html).
+# [online documentation](https://cobib.gitlab.io/cobib/cobib/config/event.html).
