@@ -5,18 +5,22 @@ from __future__ import annotations
 import logging
 import re
 import subprocess
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, List, Optional, cast
 
+from pylatexenc.latex2text import LatexNodes2Text
 from pylatexenc.latexencode import UnicodeToLatexEncoder
 
-from cobib.config import config
+from cobib.config import AuthorFormat, config
 from cobib.utils.rel_path import RelPath
 
-LOGGER = logging.getLogger(__name__)
+from .author import Author
 
 if TYPE_CHECKING:
     import cobib.parsers
 
+LOGGER = logging.getLogger(__name__)
+"""@private module logger."""
+
 
 class Entry:
     """coBib's bibliographic entry.
@@ -36,7 +40,35 @@ class Entry:
     and querying.
     """
 
-    def __init__(self, label: str, data: Dict[str, Any]) -> None:
+    _unicode_to_latex_encoder: UnicodeToLatexEncoder | None = None
+    """The singleton `UnicodeToLatexEncoder` used by all instances of this class."""
+
+    @classmethod
+    def _get_unicode_to_latex_encoder(cls) -> UnicodeToLatexEncoder:
+        """Returns the `_unicode_to_latex_encoder` singleton and constructs it if necessary."""
+        if cls._unicode_to_latex_encoder is None:
+            cls._unicode_to_latex_encoder = UnicodeToLatexEncoder(
+                non_ascii_only=True,
+                replacement_latex_protection="braces-all",
+                unknown_char_policy="keep",
+                unknown_char_warning=not config.database.format.suppress_latex_warnings
+                or LOGGER.isEnabledFor(logging.DEBUG),
+            )
+
+        return cls._unicode_to_latex_encoder
+
+    _latex_to_text_decoder: LatexNodes2Text | None = None
+    """The singleton `LatexNodes2Text` used by all instances of this class."""
+
+    @classmethod
+    def _get_latex_to_text_decoder(cls) -> LatexNodes2Text:
+        """Returns the `_latex_to_text_decoder` singleton and constructs it if necessary."""
+        if cls._latex_to_text_decoder is None:
+            cls._latex_to_text_decoder = LatexNodes2Text(keep_braced_groups=True)
+
+        return cls._latex_to_text_decoder
+
+    def __init__(self, label: str, data: dict[str, Any]) -> None:
         """Initializes a new Entry.
 
         Args:
@@ -49,7 +81,7 @@ class Entry:
 
         self._label: str = str(label)
 
-        self.data: Dict[str, Any] = {}
+        self.data: dict[str, Any] = {}
         """The actual bibliographic data."""
 
         for key, value in data.items():
@@ -98,13 +130,106 @@ class Entry:
         LOGGER.debug("Changing the label '%s' to '%s'.", self.label, label)
         self._label = str(label)
 
+    def markup_label(self) -> str:
+        """Returns the label of this entry with the rich markup based on special tags."""
+        markup_label = self.label
+
+        markup_tags: dict[str, int] = {}
+        for tag in self.tags:
+            if tag in config.theme.tags.names:
+                markup_tags[f"tag.{tag}"] = config.theme.tags.weights[tag]
+
+        for tag, _ in sorted(markup_tags.items(), key=lambda item: item[1], reverse=True):
+            markup_label = f"[{tag}]{markup_label}[/{tag}]"
+
+        return markup_label
+
     @property
-    def tags(self) -> List[str]:
+    def author(self) -> str:
+        """The author of this entry formatted as a single string.
+
+        Internally, the author(s) may be stored as one or more strings or `cobib.database.Author`
+        instances. In this case, they will be joined into a single string of unified formatting
+        before returned by this method.
+
+        Returns:
+            The string-formatted author(s) of this entry.
+
+        References:
+            - https://www.bibtex.com/f/author-field/
+        """
+        authors = self.data.get("author", "")
+
+        if isinstance(authors, str):
+            return authors
+
+        if isinstance(authors, list):
+            author_string = ""
+            for author in authors:
+                if author_string:
+                    author_string += " and "
+                author_string += str(author)
+            return author_string
+
+        return ""
+
+    @author.setter
+    def author(self, authors: str | list[str] | list[dict[str, str]] | list[Author]) -> None:
+        # pylint: disable=too-many-branches
+        """Sets the author of this entry.
+
+        The input is processed in two steps.
+        1. any encountered LaTeX commands are decoded into Unicode.
+        2. each author is parsed by `cobib.database.Author.parse`.
+
+        Args:
+            authors: can be a single string, list of strings, list of `cobib.database.Author`
+                objects, or a list of dictionaries mapping strings to strings which are treated as
+                the key-value pairs to reconstruct a `cobib.database.Author` named tuple instance.
+
+        References:
+            - https://www.bibtex.com/f/author-field/
+        """
+        if not isinstance(authors, list):
+            authors = authors.split(" and ")
+
+        dec = self._get_latex_to_text_decoder()
+
+        parsed_authors: list[str | Author] = []
+        for author in authors:
+            if isinstance(author, Author):
+                parsed_authors.append(author)
+                continue
+            if isinstance(author, dict):
+                parsed_authors.append(Author(**author))
+                continue
+
+            # we explicitly convert any latex instructions to Unicode
+            author = cast(str, dec.latex_to_text(author))
+            LOGGER.debug("Converted the author to Unicode: '%s'", author)
+
+            parsed_author = Author.parse(author)
+            if config.database.format.author_format == AuthorFormat.YAML and not isinstance(
+                parsed_author, str
+            ):
+                LOGGER.info(
+                    "Parsed the author '%s' of entry '%s' from a string to the more detailed "
+                    "information. You can consider storing it as such directly.",
+                    author,
+                    self.label,
+                    extra={"entry": self.label, "field": "author"},
+                )
+            parsed_authors.append(parsed_author)
+
+        self.data["author"] = parsed_authors
+
+    @property
+    def tags(self) -> list[str]:
         """The tags of this entry."""
-        return self.data.get("tags", [])
+        return cast(List[str], self.data.get("tags", []))
 
     @tags.setter
-    def tags(self, tags: Union[str, List[str]]) -> None:
+    def tags(self, tags: str | list[str]) -> None:
         """Sets the tags of this entry.
 
         Args:
@@ -125,17 +250,17 @@ class Entry:
         LOGGER.debug("Adding the tags '%s' to '%s'.", self.data["tags"], self.label)
 
     @property
-    def file(self) -> List[str]:
+    def file(self) -> list[str]:
         # noqa: D402 (we skip this error because file(s) raises a false negative)
         """The associated file(s) of this entry.
 
         The setter of this property will convert the strings to paths relative to the user's home
         directory. Internally, this field will always be stored as a list.
         """
-        return self.data.get("file", [])
+        return cast(List[str], self.data.get("file", []))
 
     @file.setter
-    def file(self, file: Union[str, List[str]]) -> None:
+    def file(self, file: str | list[str]) -> None:
         # noqa: D402 (we skip this error because file(s) raises a false negative)
         """Sets the associated file(s) of this entry.
 
@@ -160,12 +285,12 @@ class Entry:
         LOGGER.debug("Adding '%s' as the file to '%s'.", self.data["file"], self.label)
 
     @property
-    def url(self) -> List[str]:
+    def url(self) -> list[str]:
         """The associated URL(s) of this entry."""
-        return self.data.get("url", [])
+        return cast(List[str], self.data.get("url", []))
 
     @url.setter
-    def url(self, url: Union[str, List[str]]) -> None:
+    def url(self, url: str | list[str]) -> None:
         """Sets the associated URL(s) of this entry.
 
         Args:
@@ -187,12 +312,12 @@ class Entry:
         LOGGER.debug("Adding '%s' as the url to '%s'.", self.data["url"], self.label)
 
     @property
-    def month(self) -> str:
+    def month(self) -> str | None:
         """Returns the month."""
-        return self.data.get("month", None)
+        return cast(Optional[str], self.data.get("month", None))
 
     @month.setter
-    def month(self, month: Union[int, str]) -> None:
+    def month(self, month: int | str) -> None:
         """Sets the month."""
         months = [
             "jan",
@@ -227,52 +352,75 @@ class Entry:
                 extra={"entry": self.label, "field": "month"},
             )
 
-    def stringify(self) -> Dict[str, str]:
+    def stringify(self, *, encode_latex: bool = True, markup: bool = False) -> dict[str, str]:
         """Returns an identical entry to self but with all fields converted to strings.
 
+        Args:
+            encode_latex: whether to encode non-ASCII characters using LaTeX sequences. If this is
+                `True`, a `pylatexenc.latexencode.UnicodeToLatexEncoder` will be used to replace
+                Unicode characters with LaTeX commands.
+            markup: whether or not to add markup based on the configured special tags.
+
         Returns:
-            An `Entry` with purely string fields.
+            The data of this `Entry` as pure string fields.
         """
+        if encode_latex:
+            enc = self._get_unicode_to_latex_encoder()
         data = {}
-        data["label"] = self.label
+        data["label"] = self.markup_label() if markup else self.label
         for field, value in self.data.items():
-            if (
-                isinstance(value, list)
-                and field in config["database"]["stringify"]["list_separator"].keys()
+            if hasattr(self, field):
+                value = getattr(self, field)
+            if field == "author":
+                data[field] = str(value)
+            elif isinstance(value, list) and hasattr(
+                config.database.stringify.list_separator, field
             ):
-                data[field] = config["database"]["stringify"]["list_separator"][field].join(value)
+                data[field] = getattr(config.database.stringify.list_separator, field).join(value)
             else:
                 data[field] = str(value)
+            if encode_latex:
+                data[field] = enc.unicode_to_latex(data[field])
         return data
 
-    def escape_special_chars(self, suppress_warnings: bool = True) -> None:
-        """Escapes special characters in the bibliographic data.
+    def formatted(self) -> Entry:
+        """Formats the entry in a clean and reproducible manner.
 
-        Special characters should be escaped to ensure proper rendering in LaTeX documents. This
-        function leverages the existing implementation of the `pylatexenc` module to do said
-        conversion. The only fields exempted from the conversion are the `file` and `url` fields of
-        the `Entry.data` dictionary.
+        This includes the following:
 
-        Args:
-            suppress_warnings: if True, warnings generated by the `pylatexenc` modules will be
-                suppressed. This argument will be overwritten if the logging level is set to
-                `logging.DEBUG`.
+        1. escaping of special characters; these should be escaped to ensure proper rendering in
+           LaTeX documents. This function leverages the existing implementation of the `pylatexenc`
+           module to do said conversion. The only fields exempted from the conversion are those
+
+        2. handles the `cobib.config.config.DatabaseFormatConfig.author_format` setting and outputs
+           the `author` field in the corresponding format.
+
+        Returns:
+            A new `Entry` instance with all fields properly formatted.
         """
-        enc = UnicodeToLatexEncoder(
-            non_ascii_only=True,
-            replacement_latex_protection="braces-all",
-            unknown_char_policy="keep",
-            unknown_char_warning=not suppress_warnings or LOGGER.isEnabledFor(logging.DEBUG),
-        )
+        enc = self._get_unicode_to_latex_encoder()
+        formatted_entry = Entry(self.label, {})
         for key, value in self.data.items():
-            if key in ("file", "url"):
+            if key in config.database.format.verbatim_fields:
                 # do NOT these fields and keep any special characters
-                self.data[key] = value
+                formatted_entry.data[key] = value
                 continue
-            if isinstance(value, str):
-                self.data[key] = enc.unicode_to_latex(value)
 
-    def save(self, parser: Optional[cobib.parsers.base_parser.Parser] = None) -> str:
+            if key == "author":
+                if config.database.format.author_format == AuthorFormat.BIBLATEX:
+                    formatted_entry.data[key] = enc.unicode_to_latex(self.author)
+                elif config.database.format.author_format == AuthorFormat.YAML:
+                    formatted_entry.data[key] = value
+                continue
+
+            if isinstance(value, str):
+                formatted_entry.data[key] = enc.unicode_to_latex(value)
+            else:
+                formatted_entry.data[key] = value
+
+        return formatted_entry
+
+    def save(self, parser: cobib.parsers.base_parser.Parser | None = None) -> str:
         """Saves an entry using the parsers `dump` method.
 
         This method is mainly used by the `Database.save` method and takes care of some final
@@ -288,24 +436,26 @@ class Entry:
         Returns:
             The string-representation of this entry as produced by the provided parser.
         """
-        self.escape_special_chars(config.database.format.suppress_latex_warnings)
+        formatted_entry = self.formatted()
         if parser is None:
             # pylint: disable=import-outside-toplevel,cyclic-import
             from cobib.parsers.yaml import YAMLParser
 
             parser = YAMLParser()
-        return parser.dump(self) or ""  # `dump` may return `None`
+        return parser.dump(formatted_entry) or ""  # `dump` may return `None`
 
-    def matches(self, filter_: Dict[Tuple[str, bool], List[str]], or_: bool) -> bool:
+    def matches(
+        self, filter_: dict[tuple[str, bool], list[str]], or_: bool, ignore_case: bool = False
+    ) -> bool:
         """Check whether this entry matches the supplied filter.
 
         coBib provides an extensive filtering implementation. The filter is specified in the form
         of a dictionary whose keys consist of pairs of `(str, bool)` entries where the string
         indicates the field to match against and the boolean whether a positive (`true`) or negative
-        (`false`) match is required. The values of the dictionary must be a `List[str]`. This means
+        (`false`) match is required. The values of the dictionary must be a `list[str]`. This means
         that field types are always compared on a string-basis (this is a limitation of the targeted
         command-line interface). However, as of v3.2.0 these strings are interpreted as regex
-        patterns providing the most powerful within this framework.
+        patterns providing the most power within this framework.
 
         Some examples:
 
@@ -321,19 +471,21 @@ class Entry:
             filter_: dictionary describing the filter as explained above.
             or_ : boolean indicating whether logical OR (`true`) or AND (`false`) is used to combine
                 multiple filter items.
+            ignore_case: if True, the matching will be case-*in*sensitive.
 
         Returns:
             Boolean indicating whether this entry matches the filter.
         """
         LOGGER.debug("Checking whether entry %s matches.", self.label)
+        re_flags = re.IGNORECASE if ignore_case else 0
         match_list = []
-        stringified_data = self.stringify()
+        stringified_data = self.stringify(encode_latex=False)
         for key, values in filter_.items():
-            if key[0] not in stringified_data.keys():
+            if key[0] not in stringified_data:
                 match_list.append(not key[1])
                 continue
             for val in values:
-                if re.search(rf"{val}", stringified_data[key[0]]):
+                if re.search(rf"{val}", stringified_data[key[0]], flags=re_flags):
                     match_list.append(key[1])
                 else:
                     match_list.append(not key[1])
@@ -341,71 +493,90 @@ class Entry:
             return any(m for m in match_list)
         return all(m for m in match_list)
 
-    def search(self, query: str, context: int = 1, ignore_case: bool = False) -> List[List[str]]:
-        """Search entry contents for the query string.
+    def search(
+        self,
+        query: list[str],
+        context: int = 1,
+        ignore_case: bool = False,
+        skip_files: bool = False,
+    ) -> list[list[str]]:
+        """Search entry contents for the query strings.
 
         The entry will *always* be converted to a searchable string using the
-        `cobib.parsers.BibtexParser.dump` method. This text will then be search for `query` which
-        will be interpreted as a regex pattern.
+        `cobib.parsers.BibtexParser.dump` method. This text will then be search for each item in
+        `query` and will interpret these as regex patterns.
         If a `file` is associated with this entry, the search will try its best to recursively query
         its contents, too. However, the success of this depends highly on the configured search
-        tool, `config.commands.search.grep`.
+        tool, `cobib.config.config.SearchCommandConfig.grep`.
 
         Args:
-            query: the text to search for.
+            query: the list of regex patterns to search for.
             context: the number of context lines to provide for each match. This behaves similarly
                 to the *Context Line Control* available for the UNIX `grep` command (`--context`).
             ignore_case: if True, the search will be case-*in*sensitive.
+            skip_files: if True, associated files will *not* be searched.
 
         Returns:
             A list of lists containing the context for each match associated with this entry.
         """
-        LOGGER.debug("Searching entry %s for %s.", self.label, query)
-        matches: List[List[str]] = []
+        LOGGER.debug("Searching entry %s.", self.label)
+        matches: list[list[str]] = []
         # pylint: disable=import-outside-toplevel,cyclic-import
         from cobib.parsers.bibtex import BibtexParser
 
-        bibtex = BibtexParser().dump(self).split("\n")
+        bibtex = BibtexParser(encode_latex=False).dump(self).split("\n")
         re_flags = re.IGNORECASE if ignore_case else 0
-        re_compiled = re.compile(rf"{query}", flags=re_flags)
-        for idx, line in enumerate(bibtex):
-            if re_compiled.search(line):
-                # add new match
-                matches.append([])
-                # upper context; (we iterate in reverse in order to ensure that we abort on the
-                # first previous occurrence of the query pattern)
-                for string in reversed(bibtex[max(idx - context, 0) : min(idx, len(bibtex))]):
-                    if re_compiled.search(string):
-                        break
-                    matches[-1].insert(0, string)
-                # matching line itself
-                matches[-1].append(line)
-                # lower context
-                for string in bibtex[max(idx + 1, 0) : min(idx + context + 1, len(bibtex))]:
-                    if re_compiled.search(string):
-                        break
-                    matches[-1].append(string)
+        for query_str in query:
+            re_compiled = re.compile(rf"{query_str}", flags=re_flags)
+            for idx, line in enumerate(bibtex):
+                if re_compiled.search(line):
+                    # add new match
+                    matches.append([])
+                    # upper context; (we iterate in reverse in order to ensure that we abort on the
+                    # first previous occurrence of the query pattern)
+                    for string in reversed(bibtex[max(idx - context, 0) : min(idx, len(bibtex))]):
+                        if re_compiled.search(string):
+                            break
+                        matches[-1].insert(0, string)
+                    # matching line itself
+                    matches[-1].append(line)
+                    # lower context
+                    for string in bibtex[max(idx + 1, 0) : min(idx + context + 1, len(bibtex))]:
+                        if re_compiled.search(string):
+                            break
+                        matches[-1].append(string)
 
-        for file_ in self.file:
-            grep_prog = config.commands.search.grep
-            LOGGER.debug("Searching associated file %s with %s", file_, grep_prog)
-            with subprocess.Popen(
-                [
-                    grep_prog,
-                    *config.commands.search.grep_args,
-                    f"-C{context}",
-                    query,
-                    RelPath(file_).path,
-                ],
-                stdout=subprocess.PIPE,
-            ) as grep:
-                if grep.stdout is None:
+            if skip_files:
+                LOGGER.info("Skipping the search in associated files of %s", self.label)
+                continue
+
+            for file_ in self.file:
+                grep_prog = config.commands.search.grep
+                path = RelPath(file_).path
+                if not path.exists():
+                    LOGGER.warning(
+                        "The associated file %s of entry %s does not exist!", file_, self.label
+                    )
                     continue
-                stdout = grep.stdout
-                # extract results
-                results = stdout.read().decode().split("\n--\n")
-            for match in results:
-                if match:
-                    matches.append([line.strip() for line in match.split("\n") if line.strip()])
+
+                LOGGER.debug("Searching associated file %s with %s", file_, grep_prog)
+                with subprocess.Popen(
+                    [
+                        grep_prog,
+                        *config.commands.search.grep_args,
+                        f"-C{context}",
+                        query_str,
+                        RelPath(file_).path,
+                    ],
+                    stdout=subprocess.PIPE,
+                ) as grep:
+                    if grep.stdout is None:
+                        continue
+                    stdout = grep.stdout
+                    # extract results
+                    results = stdout.read().decode().split("\n--\n")
+                for match in results:
+                    if match:
+                        matches.append([line.strip() for line in match.split("\n") if line.strip()])
 
         return matches
