@@ -3,18 +3,30 @@
 This module provides utility methods to set up logging to different handlers.
 """
 
+from __future__ import annotations
+
 import logging
 import logging.handlers
 import sys
+from importlib import metadata
 from pathlib import Path
-from typing import Optional, Union
 
-from pkg_resources import get_distribution
+from rich.console import ConsoleRenderable, Group
+from rich.markdown import Markdown
+from rich.panel import Panel
+from rich.text import Text
+from typing_extensions import override
 
 from .rel_path import RelPath
 
+# NOTE: we add a custom HINT level which has a higher priority than WARNING and, thus, can be used
+# to provide information to the user that might be useful to see at runtime.
+logging.addLevelName(35, "HINT")
+# NOTE: we also add a custom level DEPRECATED which has an even higher priority.
+logging.addLevelName(45, "DEPRECATED")
 
-class _StderrHandler(logging.StreamHandler):
+
+class _StderrHandler(logging.StreamHandler):  # type: ignore[type-arg]
     """A logging handler hard-coded to `sys.stderr`.
 
     The reason for explicitly deriving this class, is that Python's `logging.StreamHandler` does not
@@ -22,14 +34,15 @@ class _StderrHandler(logging.StreamHandler):
     be achieved by a runtime check of the stream during the `emit` method.
     """
 
+    @override
     def emit(self, record: logging.LogRecord) -> None:
-        # pdoc will inherit the docstring from the base class
-        # noqa: D102
         self.stream = sys.stderr
         super().emit(record)
 
 
-def get_stream_handler(level: int = logging.WARNING) -> logging.StreamHandler:
+def get_stream_handler(
+    level: int = logging.WARNING,
+) -> logging.StreamHandler:  # type: ignore[type-arg]
     """Returns a basic StreamHandler logging to `sys.stderr`.
 
     Args:
@@ -45,7 +58,7 @@ def get_stream_handler(level: int = logging.WARNING) -> logging.StreamHandler:
 
 
 def get_file_handler(
-    level: Union[str, int] = "INFO", logfile: Optional[Union[str, Path]] = None
+    level: str | int = "INFO", logfile: str | Path | None = None
 ) -> logging.handlers.RotatingFileHandler:
     """Returns a `RotatingFileHandler`.
 
@@ -77,10 +90,10 @@ def get_file_handler(
     return handler
 
 
-def print_changelog(version: str, cached_version_path: Optional[str]) -> None:
-    """Prints the latest section of the CHANGELOG to stdout.
+def print_changelog(version: str, cached_version_path: str | None) -> Panel | None:
+    """Generates a `rich.Panel` to display the changelog since the last displayed version.
 
-    This function prints the contents of the CHANGELOG (extracted from the PKG-INFO metadata)
+    This function prints the contents of the CHANGELOG (extracted from the package metadata)
     between the current version (`version`) and the latest cached version (extracted from the
     provided file path).
 
@@ -88,9 +101,16 @@ def print_changelog(version: str, cached_version_path: Optional[str]) -> None:
         version: the currently running version of coBib.
         cached_version_path: the path to the file which caches the previously executed version of
             coBib. If `None`, this method exits early (thereby silencing this feature).
+
+    Returns:
+        An optional `rich.Panel` with the rendered Markdown.
     """
     if cached_version_path is None:
-        return
+        return None
+
+    _cached_version_path = RelPath(cached_version_path).path
+    if not _cached_version_path.parent.exists():
+        _cached_version_path.parent.mkdir(parents=True)
 
     try:
         current_version = version[: version.index("+")]
@@ -99,55 +119,39 @@ def print_changelog(version: str, cached_version_path: Optional[str]) -> None:
 
     cached_version = None
     try:
-        with open(RelPath(cached_version_path).path, "r", encoding="utf-8") as version_file:
+        with open(_cached_version_path, "r", encoding="utf-8") as version_file:
             cached_version = version_file.read().strip()
     except FileNotFoundError:
         pass
 
     if current_version == cached_version:
-        return
+        return None
 
-    with open(RelPath(cached_version_path).path, "w", encoding="utf-8") as version_file:
+    with open(_cached_version_path, "w", encoding="utf-8") as version_file:
         version_file.write(current_version)
 
-    lines = ["\x1b[1mHi there! It looks like you have updated coBib; here is what's new:\x1b[22m\n"]
+    groups: list[ConsoleRenderable] = []
+    groups.append(
+        Text(
+            "Hi there! It looks like you have updated coBib; here is what's new:",
+            style="bold yellow",
+        )
+    )
 
-    metadata = ""
-    try:
-        metadata = get_distribution("cobib").get_metadata("METADATA")
-    except FileNotFoundError:
-        try:
-            metadata = get_distribution("cobib").get_metadata("PKG-INFO")
-        except FileNotFoundError:
-            lines += [
-                "I wanted to show you the new changes here but was unable to query ",
-                "them from your installation. You can look them up yourself, here: ",
-                "https://gitlab.com/mrossinek/cobib/-/blob/master/CHANGELOG.md",
-            ]
+    description = str(metadata.metadata("cobib").get("description"))
 
-    num_printed_lines = -1
-    for line in metadata.splitlines():
+    lines: list[str] = []
+    started = False
+    for line in description.splitlines():
         line = line.strip()
         if line.startswith(f"## [{current_version}]"):
-            num_printed_lines = 0
+            started = True
         elif line.startswith(f"## [{cached_version}]"):
-            num_printed_lines = -1
-        elif num_printed_lines >= 20:
-            num_printed_lines = -1
-            lines.extend(
-                [
-                    "\n...\n\x1b[31m",
-                    "This output is shortened for the sake of brevity! For more information visit:",
-                    "https://gitlab.com/mrossinek/cobib/-/blob/master/CHANGELOG.md",
-                ]
-            )
+            break
 
-        if num_printed_lines >= 0:
+        if started:
             lines.append(line)
-            num_printed_lines += 1
 
-    print("\x1b[33m", end="")
-    print("\n".join(lines).strip())
-    print("\x1b[0m", end="", flush=True)
+    groups.append(Markdown("\n".join(lines)))
 
-    input("\nPress Enter to continue...")
+    return Panel(Group(*groups))
