@@ -4,17 +4,25 @@ This module provides a variety of shell helper utilities.
 """
 # pylint: disable=unused-argument
 
+from __future__ import annotations
+
 import argparse
 import contextlib
 import inspect
 import logging
 from io import StringIO
-from typing import List, Set
+
+from rich.console import Console
+from rich.prompt import PromptBase, PromptType
+from textual.app import App
 
 from .rel_path import RelPath
 
+LOGGER = logging.getLogger(__name__)
+"""@private module logger."""
 
-def list_commands(args: List[str]) -> List[str]:
+
+def list_commands(*args: str) -> list[str]:
     """Lists all available subcommands.
 
     Args:
@@ -23,13 +31,16 @@ def list_commands(args: List[str]) -> List[str]:
     Returns:
         The list of available commands.
     """
+    msg = "The _list_commands shell helper utility is deprecated and will be removed in the future!"
+    LOGGER.warning(msg)
+
     # pylint: disable=import-outside-toplevel
     from cobib import commands
 
     return [cls.name for _, cls in inspect.getmembers(commands) if inspect.isclass(cls)]
 
 
-def list_labels(args: List[str]) -> List[str]:
+def list_labels(*args: str) -> list[str]:
     """List all available labels in the database.
 
     Args:
@@ -38,6 +49,9 @@ def list_labels(args: List[str]) -> List[str]:
     Returns:
         The list of all labels.
     """
+    msg = "The _list_labels shell helper utility is deprecated and will be removed in the future!"
+    LOGGER.warning(msg)
+
     # pylint: disable=import-outside-toplevel
     from cobib.database import Database
 
@@ -45,7 +59,7 @@ def list_labels(args: List[str]) -> List[str]:
     return labels
 
 
-def list_filters(args: List[str]) -> Set[str]:
+def list_filters(*args: str) -> set[str]:
     """Lists all field names available for filtering.
 
     Args:
@@ -54,16 +68,19 @@ def list_filters(args: List[str]) -> Set[str]:
     Returns:
         The list of all available filters.
     """
+    msg = "The _list_filters shell helper utility is deprecated and will be removed in the future!"
+    LOGGER.warning(msg)
+
     # pylint: disable=import-outside-toplevel
     from cobib.database import Database
 
-    filters: Set[str] = {"label"}
+    filters: set[str] = {"label"}
     for entry in Database().values():
         filters.update(entry.data.keys())
     return filters
 
 
-def example_config(args: List[str]) -> List[str]:
+def example_config(*args: str) -> list[str]:
     """Shows the (well-commented) example configuration.
 
     Args:
@@ -84,7 +101,7 @@ class LintFormatter(logging.Formatter):
         # noqa: D107
         super().__init__(*args, **kwargs)
 
-        self.dirty_entries: Set[str] = set()
+        self.dirty_entries: set[str] = set()
 
         # pylint: disable=import-outside-toplevel
         from cobib.config import config
@@ -122,7 +139,7 @@ class LintFormatter(logging.Formatter):
             return ""
 
 
-def lint_database(args: List[str]) -> List[str]:
+def lint_database(*args: str) -> list[str]:
     """Lints the users database.
 
     Args:
@@ -190,21 +207,30 @@ def lint_database(args: List[str]) -> List[str]:
 
             name = "lint"
 
-            def execute(self, args, out=None):  # type: ignore
+            def __init__(
+                self,
+                *args: str,
+                console: Console | App[None] | None = None,
+                prompt: type[PromptBase[PromptType]] | None = None,
+            ) -> None:
+                # pylint: disable=super-init-not-called
+                self.largs = largs
+
+            @classmethod
+            def init_argparser(cls) -> None:
                 pass
 
-            @staticmethod
-            def tui(tui):  # type: ignore
+            def execute(self):  # type: ignore
                 pass
 
-        LintCommand().git(args=vars(largs))
+        LintCommand().git()
 
         return ["The following lint messages have successfully been resolved:"] + lint_messages
 
     return lint_messages
 
 
-def unify_labels(args: List[str]) -> List[str]:
+def unify_labels(*args: str) -> list[str]:
     """Unifies all labels of the database according to `config.database.format.label_default`.
 
     Without the `--apply` argument this will only print the modification which would be performed!
@@ -236,12 +262,13 @@ def unify_labels(args: List[str]) -> List[str]:
         f"label:{config.database.format.label_default}",
         "--",
         "--label",
-        "some_non_existend_label",  # this ensures that the command gets run on the entire database
+        "some_non_existent_label",  # this ensures that the command gets run on the entire database
     ]
     if largs.apply:
         modify_args = modify_args[1:]
 
     with contextlib.redirect_stderr(StringIO()) as out:
-        ModifyCommand().execute(modify_args)
+        cmd = ModifyCommand(*modify_args)
+        cmd.execute()
 
     return out.getvalue().strip().split("\n")
